@@ -5,14 +5,12 @@ use warnings;
 
 use base 'DBIx::Class::Schema';
 
-my $schema;
-
 sub db_connect {
-    my( $class ) = @_;
+    my( $schema, $filename ) = @_;
 
-    $schema //= $class->connect( "dbi:SQLite:dbname=",'','');
+    $filename ||= '/tmp/testdata';
 
-    return $schema;
+    return $schema->connect( "dbi:SQLite:dbname=$filename",'','');
 }
 
 __PACKAGE__->load_namespaces;
