@@ -1,15 +1,22 @@
 package My::Envoy::Widget;
 
     use Moose;
+    with 'Model::Envoy';
 
-    extends 'My::Envoy::Base';
+    use My::DB;
 
     sub dbic { 'My::DB::Result::Widget' }
 
+    my $schema;
+
+    sub _schema {
+        $schema ||= My::DB->db_connect('/tmp/envoy');
+    }
+
     has 'id' => (
         is => 'ro',
         isa => 'Num',
-        traits => ['Envoy','DBIC'],
+        traits => ['DBIC'],
         primary_key => 1,
 
     );
@@ -17,25 +24,20 @@ package My::Envoy::Widget;
     has 'name' => (
         is => 'rw',
         isa => 'Maybe[Str]',
-        traits => ['Envoy','DBIC'],
+        traits => ['DBIC'],
     );
 
     has 'no_storage' => (
         is => 'rw',
         isa => 'Maybe[Str]',
-        traits => ['Envoy'],
     );
 
     has 'parts' => (
         is => 'rw',
         isa => 'ArrayRef[My::Envoy::Part]',
-        traits => ['Envoy','DBIC'],
+        traits => ['DBIC','Envoy'],
         rel => 'has_many',
-    );
-
-    has 'no_envoy' => (
-        is => 'rw',
-        isa => 'Str'
+        coerce => 1,
     );
 
 1;
\ No newline at end of file
